@@ -18,7 +18,8 @@ from framework.utils.date_util import DateUtil
 from framework.utils.common import snake_to_pascal, SingletonFaker
 from framework.global_attribute import GlobalAttribute, _FRAMEWORK_CONTEXT, CONTEXT
 from framework.exceptions import ValidateException, RenderException, RequestException, GetAccountError, GetAppHttpError
-from framework.utils.mock_util import get_customized_kytmock, set_customized_kytmock, PaymentType, RiskLevel, IsDelayed
+from framework.utils.mock_util import get_customized_kytmock, set_customized_kytmock, PaymentType, RiskLevel, IsDelayed, \
+    mock_mq
 
 from handlers.extend_base_test_case_attr import ExtendBaseTestCase
 from config.settings import UNAUTHORIZED_CODE, FAKER_LANGUAGE
@@ -190,3 +191,12 @@ class BaseTestCase(ExtendBaseTestCase):
 
         """
         return set_customized_kytmock(self.context.get("env"), request_id, payment_type, risk_level, is_delayed)
+
+    def mock_mq_message(self,target_exchange,exchange_type,message,routing_key:str=None):
+        """
+        target_exchange:目标交换机名称
+        exchange_type：交换机类型，枚举：fanout，direct，topic，header
+        message：消息体，json格式
+        routing_key: 路由关键字，默认为null
+        """
+        return  mock_mq(self.context.get("env"),target_exchange,exchange_type,message,routing_key)
\ No newline at end of file
