@@ -21,7 +21,7 @@ class RenderData(object):
         self.data = data
         self.request = data.get("request")
         try:
-            self.scenario = Box(data.get("_scenario").get("data", dict()))
+            self.scenario = Box(data.get("_scenario").get("data") or dict())
         except AttributeError:
             self.scenario = dict()
         self.context = CONTEXT
